@@ -1,5 +1,6 @@
 import argparse
 import sys
+from pathlib import Path
 from typing import Mapping, Optional
 
 from dunamai import check_version, Version, Pattern, Style, Vcs, VERSION_SOURCE_PATTERN
@@ -26,6 +27,13 @@ common_sub_args = [
         "dest": "dirty",
         "help": "Include dirty flag if applicable. Ignored when --format is used",
     },
+    {
+        "vcs": [Vcs.Git],
+        "triggers": ["--ignore-untracked"],
+        "action": "store_true",
+        "dest": "ignore_untracked",
+        "help": "Ignore untracked files when determining whether the repository is dirty",
+    },
     {
         "triggers": ["--tagged-metadata"],
         "action": "store_true",
@@ -49,6 +57,10 @@ common_sub_args = [
             " as a named preset, which may be one of the following: {}"
         ).format(", ".join(["`{}`".format(x.value) for x in Pattern])),
     },
+    {
+        "triggers": ["--pattern-prefix"],
+        "help": "Insert this after the pattern's start anchor (`^`).",
+    },
     {
         "triggers": ["--format"],
         "help": (
@@ -79,10 +91,11 @@ common_sub_args = [
         "action": "store_true",
         "dest": "strict",
         "default": False,
-        "help": (
-            "Elevate warnings to errors."
-            " When there are no tags, fail instead of falling back to 0.0.0"
-        ),
+        "help": ("Elevate warnings to errors." " When there are no tags, fail instead of falling back to 0.0.0"),
+    },
+    {
+        "triggers": ["--path"],
+        "help": "Directory to inspect, if not the current working directory",
     },
     {
         "triggers": ["--debug"],
@@ -111,6 +124,12 @@ common_sub_args = [
         "default": False,
         "help": "Get the full commit hash instead of the short form",
     },
+    {
+        "triggers": ["--commit-length"],
+        "dest": "commit_length",
+        "type": int,
+        "help": "Use this many characters from the start of the full commit hash",
+    },
     {
         "vcs": [Vcs.Git],
         "triggers": ["--tag-branch"],
@@ -221,8 +240,12 @@ def build_parser(
     return parser
 
 
+def get_parser() -> argparse.ArgumentParser:
+    return build_parser(cli_spec)
+
+
 def parse_args(argv=None) -> argparse.Namespace:
-    return build_parser(cli_spec).parse_args(argv)
+    return get_parser().parse_args(argv)
 
 
 def from_stdin(value: Optional[str]) -> Optional[str]:
@@ -250,8 +273,24 @@ def from_vcs(
     tag_branch: Optional[str],
     full_commit: bool,
     strict: bool,
+    path: Optional[Path],
+    pattern_prefix: Optional[str],
+    ignore_untracked: bool,
+    commit_length: Optional[int],
 ) -> None:
-    version = Version.from_vcs(vcs, pattern, latest_tag, tag_dir, tag_branch, full_commit, strict)
+    version = Version.from_vcs(
+        vcs,
+        pattern,
+        latest_tag,
+        tag_dir,
+        tag_branch,
+        full_commit,
+        strict,
+        path,
+        pattern_prefix,
+        ignore_untracked,
+        commit_length,
+    )
 
     for concern in version.concerns:
         print("Warning: {}".format(concern.message()), file=sys.stderr)
@@ -270,6 +309,8 @@ def main() -> None:
             tag_dir = getattr(args, "tag_dir", "tags")
             tag_branch = getattr(args, "tag_branch", None)
             full_commit = getattr(args, "full_commit", False)
+            ignore_untracked = getattr(args, "ignore_untracked", False)
+            commit_length = getattr(args, "commit_length", None)
             from_vcs(
                 Vcs(args.vcs),
                 args.pattern,
@@ -285,6 +326,10 @@ def main() -> None:
                 tag_branch,
                 full_commit,
                 args.strict,
+                Path(args.path) if args.path is not None else None,
+                args.pattern_prefix,
+                ignore_untracked,
+                commit_length,
             )
         elif args.command == "check":
             version = from_stdin(args.version)
